from distutils.core import setup
setup(
  name = 'ybc_tel',
  packages = ['ybc_tel'],
  version = '1.0.0',
  description = 'Get All Cars Brand',
  long_description='Get All Cars Brand From juhe API',
  author = 'KingHS',
  author_email = '382771946@qq.com',
  keywords = ['pip3', 'tel', 'python3','python','telphone'],
  license='MIT',
)
